@@ -1,9 +1,9 @@
-import { Injectable } from "@angular/core"
-import { NgLifeCycleEvents } from "@synerty/vortexjs"
+import { Injectable } from "@angular/core";
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
 import {
     ChunkedIndexLoaderService,
-    ChunkedIndexResultI
-} from "./_private/chunked-index-loader"
+    ChunkedIndexResultI,
+} from "./_private/chunked-index-loader";
 
 // ----------------------------------------------------------------------------
 /** ChunkedIndex Cache
@@ -17,12 +17,10 @@ import {
  */
 @Injectable()
 export class ChunkedIndexService extends NgLifeCycleEvents {
-    
     constructor(private chunkedIndexLoader: ChunkedIndexLoaderService) {
-        super()
-        
+        super();
     }
-    
+
     /** Get Chunkeds
      *
      * Get the objects for key from the index..
@@ -32,7 +30,6 @@ export class ChunkedIndexService extends NgLifeCycleEvents {
         modelSetKey: string,
         keys: string[]
     ): Promise<ChunkedIndexResultI> {
-        return this.chunkedIndexLoader.getChunkeds(modelSetKey, keys)
+        return this.chunkedIndexLoader.getChunkeds(modelSetKey, keys);
     }
-    
 }
