@@ -3,6 +3,7 @@ from abc import ABCMeta
 from collections import defaultdict
 from typing import List, Dict
 
+from peek_plugin_base.PeekVortexUtil import peekServerName
 from twisted.internet.defer import DeferredList, inlineCallbacks, Deferred
 from vortex.DeferUtil import vortexLogFailure
 from vortex.Payload import Payload
@@ -39,6 +40,14 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
             self._updateFromServerFilt, self._processObserve
         )
 
+        # Tell the logic service that this vortexUuid is interested in its data
+        VortexFactory.sendVortexMsg(
+            vortexMsgs=PayloadEnvelope(
+                filt=self._updateFromServerFilt
+            ).toVortexMsg(),
+            destVortexName=peekServerName,
+        )
+
         self._uuidsObserving = set()
 
     def shutdown(self):
